GnortClient is the client for emitting dogstatsd metrics to a statsd server. You usually don’t need to poke around this module, you just instantiate clients for use with MetricsRegistry.
Structs
- Gnort
Client - The only metrics client is synchronous because you should be aggregating your metrics using crate::registry::MetricsRegistry.